package edu.umd.dawn.common.services;

import com.mongodb.client.MongoClient;
import com.mongodb.client.MongoClients;
import com.mongodb.client.MongoCollection;
import com.mongodb.client.MongoDatabase;
import edu.umd.dawn.common.enums.Role;
import edu.umd.dawn.common.exceptions.BaseExceptions;
import edu.umd.dawn.common.exceptions.DawnException;
import java.util.Optional;
import org.bson.Document;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

@Component
public class UserAuthService {

    private MongoClient mongoClient;
    private MongoDatabase mongoDatabase;

    @Value("${common.annotation.mongodb.uri}")
    private String uri;

    @Value("${common.annotation.mongodb.database}")
    private String db;

    protected MongoDatabase getDatabase() {
        if (mongoClient == null) {
            mongoClient = MongoClients.create(uri);
        }
        if (mongoDatabase == null) {
            mongoDatabase = mongoClient.getDatabase(db);
        }
        return mongoDatabase;
    }

    public Role getUserRole(String userId) {
        MongoDatabase database = getDatabase();
        MongoCollection<Document> collection = database.getCollection("users");

        Document query = new Document();
        query.put("_id", userId);

        // should prob throw an auth type error
        Document doc = Optional.of(collection.find(query).first())
                .orElseThrow(() -> new DawnException(BaseExceptions.NOT_FOUND));

        int role = (int) doc.get("role");

        return Role.fromInt(role);
    }
}
